@@ -50,6 +50,8 @@ SIOCGIFHWADDR = 0x8927
 
 # Resources allocated
 IFF_RUNNING = 0x40
+IFF_MASTER = 0x400
+IFF_SLAVE = 0x800
 
 # ip digit from 0|1-255|254 (template)
 IP_DIG = "[%s-9]|(?:1[0-9]|[1-9])[0-9]|2[0-4][0-9]|25[0-%s]"
@@ -226,8 +228,24 @@ def getInterfaces():
     """
     Get available interfaces (discard which hasn't device)
     """
+
+    def filter_ethernet(x):
+        full_dn = path.join(SYSFS_NET_PATH, x)
+        # исплючить loopback
+        if readFile(path.join(full_dn, "type")).strip() != "1":
+            return False
+        # если физическое утройство
+        if path.lexists(path.join(full_dn, "device")):
+            return True
+        # исключить мосты
+        if path.lexists(path.join(full_dn, "brport")):
+            return False
+        if path.lexists(path.join(full_dn, "bridge")):
+            return False
+        return True
+
     return sorted(
-        filter(lambda x: path.exists(path.join(SYSFS_NET_PATH, x, "device")),
+        filter(filter_ethernet,
                listDirectory(SYSFS_NET_PATH)))
 
 
@@ -243,8 +261,7 @@ def getIp(iface):
     ip = struct.unpack('16sH2x4s8x', res)[2]
     return socket.inet_ntoa(ip)
 
-
-def getPlugged(iface):
+def checkFlag(iface, flag):
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00' * 14)
     try:
@@ -253,8 +270,16 @@ def getPlugged(iface):
         return False
     finally:
         sockfd.close()
-    return bool(struct.unpack('16sH2x4s8x', res)[1] & IFF_RUNNING)
+    return bool(struct.unpack('16sH2x4s8x', res)[1] & flag)
 
+def getPlugged(iface):
+    return checkFlag(iface, IFF_RUNNING)
+
+def isSlaveInterface(iface):
+    return checkFlag(iface, IFF_SLAVE)
+
+def isMasterInterface(iface):
+    return checkFlag(iface, IFF_MASTER)
 
 def getMask(iface):
     """
